notify_and_unset_env

Function notify_and_unset_env 

pub unsafe fn notify_and_unset_env(state: &[NotifyState<'_>]) -> Result<()>
Sends the service manager a list of state changes.

This does the same as the notify and unsets the NOTIFY_SOCKET environment variable afterwards, so that child processes no longer inherit the variable.

Safety

Since this function calls std::env::remove_var, it has the same safety preconditions. See its safety documentation for more details. It can only be safely called before threads are spawned, in particular before any tokio runtime initialization or #[tokio::main].