watchdog_enabled_and_unset_env

Function watchdog_enabled_and_unset_env 

pub unsafe fn watchdog_enabled_and_unset_env() -> Option<Duration>
Asks the service manager for enabled watchdog.

This does the same as the watchdog_enabled and unsets the WATCHDOG_PID and WATCHDOG_USEC environment variables afterwards, so that child processes no longer inherit the variable.

Safety

Since this function calls std::env::remove_var, it has the same safety preconditions. See its safety documentation for more details. It can only be safely called before threads are spawned, in particular before any tokio runtime initialization or #[tokio::main].